from typing import Optional

from acslib.base import AccessControlSystem
from acslib.ccure.connection import CcureConnection


class CcureACS(AccessControlSystem):
    """."""

    def __init__(self, connection: Optional[CcureConnection] = None):
        """."""
        super().__init__(connection=connection)
        if not self.connection:
            self.connection = CcureConnection()
        self.logger = self.connection.logger
        self.request_options = {}
        self.search_filter = None

    @property
    def config(self):
        """."""
        return self.connection.config



from enum import Enum


class ClearanceItemType(Enum):
    DOOR = "door"
    ELEVATOR = "elevator"

    @property
    def complete(self):
        if self == self.DOOR:
            return "SoftwareHouse.NextGen.Common.SecurityObjects.Door"
        if self == self.ELEVATOR:
            return "SoftwareHouse.NextGen.Common.SecurityObjects.Elevator"



from acslib.base import ACSRequestResponse
from acslib.base.connection import ACSRequestData, ACSRequestMethod
from acslib.ccure.base import CcureACS
from acslib.ccure.crud import CcureAPI, CcurePersonnel, CcureClearance, CcureCredential
from acslib.ccure.filters import ClearanceFilter, PersonnelFilter, CredentialFilter
